.. py:module:: colliderscope

API Reference
=============
Colliderscope contains a small library of routines and data structures to
produce interactive HTML displays on particle physics data.

Producing figures
-----------------
Functions which output visualisations.

.. python-apigen-group:: figs

Data structures
---------------
Data structures to represent styles and plottable data.

.. python-apigen-group:: data

Helper functions
----------------
Convenience functions to make producing plots easier.

.. python-apigen-group:: helpers
